======
os-ken
======

A component-based software defined networking framework in OpenStack.

This is a fork of the Ryu library tailored for OpenStack Neutron.

* License: Apache License, Version 2.0
* Documentation: https://docs.openstack.org/os-ken/latest/
* Source: https://git.openstack.org/cgit/openstack/os-ken
* Bugs: https://bugs.launchpad.net/os-ken
* Release Notes: https://docs.openstack.org/releasenotes/os-ken
